@@ -3,7 +3,7 @@ package Mnet;
 # version number used by Makefile.PL
 #   these should be set to "dev", expect when creating a new release
 #   refer to developer build notes in Makefile.PL for more info
-our $VERSION = "5.23";
+our $VERSION = "5.24";
 
 =head1 NAME
 
@@ -11,7 +11,7 @@ Mnet - Testable network automation and reporting
 
 =head1 SYNOPSIS
 
-    # sample script to report Loopback0 ip on cisco devices
+    # sample.pl script to report Loopback0 ip on cisco devices
     #
     #   demonstrates typical use of all major Mnet modules
     #
@@ -146,8 +146,9 @@ a list of devices, using command line arguments and a device list file.
 
 =item *
 
-L<Mnet::Log> can facilitate easy log, debug, alert and error output from
-automation scripts, outputs can be redirected to per-device files.
+L<Mnet::Log> and L<Mnet::Tee> modules facilitate easy log, debug, alert and
+error output from automation scripts, along with redirection to per-device
+output files.
 
 =item *
 
@@ -188,6 +189,83 @@ Check your PERL5LIB environment variable if INSTALL_BASE was used, or if you
 copied the lib/Mnet directory somewhere instead of using the included
 Makefile.PL script. Refer to L<ExtUtils::MakeMaker> for more information
 
+=head1 FAQ
+
+Below are answers to some frequently asked questions.
+
+=head2 How should I get started?
+
+Copy the sample script code from the SYNOPSIS above to a new .pl file, read
+through the comments, make changes as necessary, use the --debug cli option to
+troubleshoot execution.
+
+=head2 What's the easiest way to get more log output?
+
+Use both the L<Mnet::Log> and L<Mnet::Opts::Set::Debug> modules in your script
+for more output, mostly from other Mnet modules unless you add L<Mnet::Log>
+calls, which are a compatible subset of log4perl calls, to your script.
+
+=head2 How should passwords be secured?
+
+Environment variables should be used to provide passwords for scripts, not
+command line options. Command line options can be seen in the system process
+list by other users.
+
+The L<Mnet::Opts::Cli> new method allows a named environment variable to be
+specified that will also be parsed for command line options. Your script can
+be called from a shell script containing authentication, which is accessible
+only to authorized users, such as in the example below:
+
+    #!/bin/sh
+    #   sample.sh script, chmod 700 to restrict access to current user
+    #   works with Mnet::Opts calls in above SYNOPISIS sample.pl script
+    #   "$@" passes throuh all command line options, modify as needed
+    export Mnet='--username <user> --password <secret>'
+    perl -- sample.pl "$@"
+
+The L<Mnet::Opts::Cli> module define function has a redact property that should
+be set for password options so that the value of the option is value is always
+redacted form L<Mnet::Log> outputs.
+
+Also note that the L<Mnet::Expect> module log_expect method is used by the
+L<Mnet::Expect::Cli> modules to temporarily disable expect session logging
+during password entry. Any user code bypassing the L<Mnet::Expect::Cli>
+modules to send passwords directly, using the expect method in the
+L<Mnet::Expect> module, may need to do the same.
+
+=head2 Why should I use the Mnet::Expect module?
+
+The L<Mnet::Expect> module works with the L<Mnet::Log> and L<Mnet::Opts::Cli>
+modules, for easy logging of normal L<Expect> module activity, with extra
+options for logging, debugging, raw pty, and session tty rows and columns.
+
+However, you still have to handle all the expect session details, including
+send and expect calls for logging in, detecting of command prompts, capturing
+output, etc. It's easier to use the L<Mnet::Expect::Cli> module which handles
+all of this, if you can.
+
+=head2 Why should I use the Mnet::Expect::Cli module?
+
+The L<Mnet::Expect::Cli> module makes it easy to login and obtain outputs from
+command line interfaces, like ssh. This module builds on the L<Mnet::Expect>
+module mentioned above, adding features to handle a variety of typical username
+and password prompts, command prompts, pagination prompts on long outputs, and
+caching of session command output.
+
+This module also works with the L<Mnet::Test> module, allowing expect session
+activity to be recorded and replayed while offline. This can be of tremendous
+value, both during development, and for sustainability.
+
+Refer also the the L<Mnet::Expect::Cli::Ios> module mentioned below, which has
+a couple of features relevant when working with cisco ios and other similar
+devices.
+
+=head2 Why should I use the Mnet::Expect::Cli::Ios module?
+
+The L<Mnet::Expect::Cli::Ios> builds on the L<Mnet::Expect::Cli> module
+mentioned above, also handling enable mode authentication, the prompt changes
+going from user to enable mode, and the prompt changes in configuration modes.
+
 =head1 AUTHOR
 
 The L<Mnet> perl distribution has been created and is maintained by Mike Menza.
@@ -196,7 +274,7 @@ at <mmenza@cpan.org> with any comments or questions.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006, 2013-2022 Michael J. Menza Jr.
+Copyright 2006 Michael J. Menza Jr.
 
 L<Mnet> is free software: you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free Software
