@@ -28,12 +28,13 @@ Mnet::Expect::Cli - Expect sessions to command line interfaces
 
 =head1 DESCRIPTION
 
-Mnet::Expect::Cli can be used to spawn L<Expect> processes, which can be
-used to programmatically control command line sessions to devices, with
-support for L<Mnet> options, logging, caching, and testing.
+Mnet::Expect::Cli can be used to spawn L<Expect> processes, which can be used
+to programmatically control command line sessions to devices, with support
+for L<Mnet> options, logging, caching, and testing.
 
-Refer to the perl L<Expect> module for more information. Also refer to the
-L<Mnet::Expect> and L<Mnet::Expect::Cli::Ios> modules.
+Refer to the L<Mnet::Expect> module, whose methods are inherited by objects
+created with this module. Also refer to L<Mnet::Expect::Cli::Ios>, which
+builds on this module,
 
 =head1 METHODS
 
@@ -46,6 +47,7 @@ use warnings;
 use strict;
 use parent qw( Mnet::Expect );
 use Carp;
+use Mnet;
 use Mnet::Dump;
 use Mnet::Opts::Cli::Cache;
 use Time::HiRes;
@@ -71,13 +73,13 @@ in the L<Mnet::Expect> module new method:
     paging_re       default handles common prompts, refer to paging_re
     password        set to password for spawned command, if needed
     password_in     stderr prompt for stdin entry of password if not set
-    password_re     undef to skip password/passcode prompt detection
-    prompt_re       undef to skip cli prompt detect, refer to prompt_re
+    password_re     undef to skip password/code/phrase prompt detection
+    prompt_re       undef to disable post-login prompt detect, see below
     timeout         seconds for Expect restart_timeout_upon_receive
     username        set to username for spawned command, if needed
     username_re     undef to skip login/user/username promt detection
 
-    An error is issued if there are login problems.
+An error is issued if there are login problems.
 
 For example, the following call will start an ssh expect session to a device
 with host key checking disabled:
@@ -92,6 +94,21 @@ with text that appears in login banners. For example:
 
     (?i)(closed|error|denied|fail|incorrect|invalid|refused|sorry)
 
+A default prompt_re regex string is used by this method to detect and confirm
+the specific prompt text in use on a connected system, after login. When this
+happens prompt_re is rewritten with the detected prompt text, which is used by
+the command method to detect the end of command output.
+
+By default prompts ending with $ % # : > are detected, this can be changed by
+setting prompt_re to a different regex string when calling the new method, or
+disabled by setting to undef, note that prompt_re needs to match the entire
+prompt line, not just the ending:
+
+    (^|\r|\n)\S.*(\$|\%|#|:|>) ?(\r|\n|$)
+
+Refer also to the prompt_re method which can be used to examine or change
+prompt_re for an existing session returned by this method.
+
 Refer to the L<Mnet::Expect> module for more information.
 
 =cut
@@ -108,41 +125,34 @@ Refer to the L<Mnet::Expect> module for more information.
     # create hash that will become new object from input opts hash
     my $self = $opts;
 
-    # note default options for this class
+    # note default options for this class, refer also to Mnet::Expect defaults
     #   includes recognized cli opts and opts for this object
-    #       failed_re default based on educated guess, specifics noted below:
-    #           /(closed|error|denied|fail|incorrect|invalid|refused|sorry)/i
-    #           junos telnet =~ /^Login incorrent/m
-    #       password_re default based on educated guess, specifics noted below:
-    #           junos telnet =~ /^Password:$/m
-    #       prompt_re default based on educated guess, specifics noted below:
-    #           junos telnet =~ /^\S+> $/mi
-    #       username_re default based on educated guess, specifics noted below:
-    #           junos telnet =~ /^login: $/m
-    #   the following keys starting with underscore are used internally:
-    #       _command_cache_content => hash ref, refer to _command_cache_clear
-    #       _command_cache_counter => integer, refer to _command_cache_clear
-    #       _password_ => causes password value to be hidden in opts debug
     #   update perldoc for this sub with changes
-    #   refer also to Mnet::Expect defaults
     my $defaults = {
-        _command_cache_content => {},
-        _command_cache_counter => 0,
+        _command_cache_content => {}, # internal, see _command_cache_clear
+        _command_cache_counter => 0,  # internal, see _command_cache_clear
         delay       => 250,
         eol_unix    => 1,
+        # failed_re default undef to be safe, refer to perldoc for more info
+        #   junos telnet =~ /^Login incorrent/m
         failed_re   => undef,
         log_login   => undef,
         paging_key  => ' ',
         paging_re   => '(--more--|---\(more( \d\d?%)?\)---)',
         password    => undef,
-        _password_  => undef,
         password_in => undef,
-        password_re => '(?i)pass(word|code):?\s*(\r|\n)?$',
+        # password_re default based on educated guess, specifics noted below:
+        #   junos telnet =~ /^Password:$/m
+        password_re => '(?i)pass(code|phrase|word):?\s*(\r|\n)?$',
+        # prompt_re default based on educated guess, specifics noted below:
+        #   junos telnet =~ /^\S+> $/mi
         prompt_re   => '(^|\r|\n)\S.*(\$|\%|#|:|>) ?(\r|\n|$)',
         record      => undef,
         replay      => undef,
         timeout     => 30,
         username    => undef,
+        # username_re default based on educated guess, specifics noted below:
+        #   junos telnet =~ /^login: $/m
         username_re => '(?i)(login|user(name)?):?\s*(\r|\n)?$',
     };
 
@@ -234,7 +244,11 @@ sub _login {
             if ($self->{password_in}) {
                 $self->debug("_login password_in prompt starting");
                 {
-                    local $SIG{INT} = sub { system("stty echo 2>/dev/null") };
+                    local $SIG{INT} = sub {
+                        system("stty echo 2>/dev/null");
+                        syswrite STDERR, "\n\n";
+                        $self->fatal("interrupt signal received");
+                    };
                     syswrite STDERR, "\nEnter $self->{password_in}: ";
                     system("stty -echo 2>/dev/null");
                     chomp($password = <STDIN>);
@@ -271,6 +285,7 @@ sub _login {
     #   clear _log_filter, which may have been set when password was sent
     #   clear expect buffer before sending cr, to flush out banner text, etc
     #   set prompt_re to detected command prompt when finished
+    #   prompt_truncate in Mnet::Expect::Cli::Ios must match prompt_re changes
     #   reset log_expect level back to it's prior value before returning
     my ($prompt1, $prompt2, $attempts) = ("", "", 3);
     foreach my $attempt (1.. $attempts) {
@@ -349,9 +364,9 @@ sub close {
 
     $expect->close($command)
 
-This method sends closes the current expect session, sending the optional
-input command first. Timeouts are gracefully handled. Refer to the close
-method in the L<Mnet::Expect> module for more information.
+This method sends closes the current expect session, sending the optional input
+command first. Timeouts and disconnects are gracefully handled. Refer to the
+close method in the L<Mnet::Expect> module for more information.
 
 =cut
 
@@ -379,36 +394,43 @@ sub command {
 
     $output = $expect->command($command, $timeout, \@prompts)
 
-This method returns output from the specified command from the current expect
-cli session, or undefined if there was a timeout.
+This method returns output from the specified command sent to the current
+expect cli session, or undefined if there was a timeout.
 
-The timeout input argument can be used to override the timeout for the current
-object.
+Note that this method caches command output, so that if the exact same command
+is sent repeatedly the first output from the connected device will be returned
+for subsequent calls. Refer to the command_cache_clear method for more info.
+
+The optional timeout argument can be used to override the default timeout for
+the new object.
+
+The optional prompts reference argument can be used to handle prompts that may
+occur when running a command, such as confirmation prompts. It should contain
+pairs of regex strings and responses. The regex string values should be what
+goes in between the forward slash characters of a regular expression. The
+response can be a string that is sent to the expect session with or without a
+carraige return, or may be a code reference that gets the current object and
+output as input args and returns a response string. A null prompt regex string
+is activated for timeouts and disconnects. An undef prompt response causes an
+immediate return of output.
 
     # sends $command, uses default timeout, defines some prompts
     my $output = $expect->command($command, undef, [
 
-        # send 1.2.3.4 if matched by expect -re /ip/
-        'ip' => '1.2.3.4\r',
+        # send 1.2.3.4 and carraige return if matched by expect -re /ip/
+        'ip' => "1.2.3.4\r",
 
         # code ref
         'confirm? ' => sub { my $output = shift; return "y" },
 
-        # returns prior output on timeout, might be undef
-        undef => undef,
+        # returns received output on timeout, might be undef
+        '' => undef,
 
     ]);
 
-The prompts reference argument can be used to handle prompts that occur after
-entering a command, such as confirmation prompts. It should contain pairs of
-regex strings and responses. The regex string values should be what goes in
-between the forward slash characters of a regular expression. The response can
-be a string that is sent to the expect session without a carraige return, or
-may be a code reference that gets the current object and output as input args
-and returns a response string. An null prompt regex string is activated for
-timeouts. An undef prompt response causes an immediate return of output.
-
-Refer also to the command_cache_clear method for more info.
+By default the end of command output is recognized using the prompt_re string
+detected by the new method after login. Refer to the new and prompt_re methods
+for more information.
 
 =cut
 
@@ -474,7 +496,7 @@ sub _command_expect {
     my $output = undef;
 
     # store input prompt regexes and responses, also timeout regex/response
-    #   timeout prompt is separated because it's not an expect -re like others
+    #   null timeout prompt is separate, it's not an expect -re like others
     my $prompt_regexes = [];
     my $prompt_responses = [];
     my ($timeout_regex_flag, $timeout_response) = (undef, undef);
@@ -487,9 +509,10 @@ sub _command_expect {
         } else {
             push @$prompt_regexes, $regex;
             push @$prompt_responses, $response;
+            $regex = "/$regex/";
         }
         $response = Mnet::Dump::line($response);
-        $self->debug("_command_expect input prompt /$regex/ = $response");
+        $self->debug("_command_expect input prompt $regex = $response");
     }
 
     # prepare regexes used for expect call
@@ -518,7 +541,7 @@ sub _command_expect {
         #   return prior output if response undef or code ref returning undef
         #   otherwise return undef output
         if (not $expect and $timeout_regex_flag) {
-            $self->debug("_command_expect matched prompts null for timeout");
+            $self->debug("_command_expect matched prompts (null=timeout)");
             $self->_command_expect_prompt($timeout_response, $output) // last;
             $output = undef;
             last;
@@ -569,7 +592,7 @@ sub _command_expect {
     # remove echod command from start of output, fix eol chars, remove last eol
     #   normalize eol chars to be unix newlines only if eol_unix opt is set
     if (defined $output) {
-        $output =~ s/^\Q$command\E\s*\r?\n?//;
+        $output =~ s/^\s*\Q$command\E\s*\r?\n?//;
         if ($self->{eol_unix}) {
             $output =~ s/\r\n/\n/g;
             $output =~ s/\r/\n/g;
@@ -632,7 +655,7 @@ sub command_cache_clear {
 
 This method can be used to clear the cache used by the command method.
 
-Normally the the command method caches the outputs for all executed commands,
+Normally the command method caches the outputs for all executed commands,
 returning cached output when the same command is executed subsequently. When
 the cache is cleared the command method will execute the next instance of any
 specific command instead of returning cached output.
@@ -726,14 +749,25 @@ sub prompt_re {
 
     $prompt_re = $expect->prompt_re($prompt_re)
 
-Get and/or set new prompt_re for the current object.
+This method can be used to get and/or set the prompt_re regex string for an
+existing object, which is used by the command method to detect the end of
+output for a sent command. The prompt_re regex string should be specific
+enough to detect the cli prompt without matching any other command outputs.
 
-By default prompts that end with $ % # : > are recognized, and the first prompt
-detected after login is used as prompt_re for the rest of the expect session.
+By default the new method sets a device specific prompt_re for the rest of
+the session from the first prompt detected after login, confirmed by sending
+a carraige return and getting the same specifc prompt back again. This prompt
+detection can be adjusted or disabled, refer to the new method for more info.
 
-Note that prompt_re should start with a regex caret symbol and end with a regex
-dollar sign, to ensure it is accurately detected. Also the /Q and /E escape
-sequences do not appear to work in an expect regex.
+Note that normally prompt_re should start with a regex caret symbol, and end
+with a regex dollar sign, so that all characters in the command prompt line
+are matched, and to avoid spurrious matches in command outputs. Be aware of
+any spaces that at the end of a prompt, as in the example below:
+
+    $expect->prompt_re('^st-city-dev> $');
+
+Also note that the /Q and /E escape sequences do not appear to be recognized by
+expect, and they should not be used in prompt_re.
 
 =cut
 
