@@ -80,6 +80,7 @@ use strict;
 use 5.008;
 use Carp;
 use Exporter qw( import );
+use Mnet;
 use Mnet::Opts;
 use Mnet::Opts::Cli::Cache;
 use Mnet::Version;
@@ -113,14 +114,17 @@ BEGIN {
     # declare sub used by SIG handlers to log error and stack trace info
     sub _sig_handler {
         my ($label, $caller, $error, $sev) = (shift, shift, shift, 7);
+        my $opts = Mnet::Opts::Cli::Cache::get({});
         $sev = 3 if not defined $Mnet::Log::error;
         output(undef, "ERR", 3, $caller, "$label, $error");
-        output(undef, "err", $sev, $caller, "$label, $_")
-            foreach split(/\n/, Carp::longmess());
-        output(undef, "err", $sev, $caller, "$label, \$! = $!") if $! ne "";
-        output(undef, "err", $sev, $caller, "$label, \$@ = $@") if $@ ne "";
-        output(undef, "err", $sev, $caller, "$label, \$? = $?") if $? ne "";
-        output(undef, "err", $sev, $caller, "$label, \$^E = $^E") if $^E ne "";
+        if (not $opts->{quiet} and not $label =~ /^perl (die|warn),\s(.*)/) {
+            output(undef, "err", $sev, $caller, "$label, $_")
+                foreach split(/\n/, Carp::longmess());
+            output(undef,"err",$sev,$caller,"$label, \$! = $!") if $! ne "";
+            output(undef,"err",$sev,$caller,"$label, \$@ = $@") if $@ ne "";
+            output(undef,"err",$sev,$caller,"$label, \$? = $?") if $? ne "";
+            output(undef,"err",$sev,$caller,"$label, \$^E = $^E") if $^E ne "";
+        }
     }
 
     # trap perl die signal, log as error and exit with a failed status
@@ -153,7 +157,7 @@ BEGIN {
     #   output a linefeed to stderr after ^C put there by shell
     $SIG{INT} = sub {
         syswrite STDERR, "\n";
-        output(undef, "ERR", 3, scalar(caller), "terminate signal received");
+        output(undef, "ERR", 3, scalar(caller), "interrupt signal received");
         exit 1;
     };
 
@@ -168,17 +172,9 @@ BEGIN {
 
 
 
-# init Mnet::Tee stdout debug bypass, and cli options used by this module
+# init cli options used by this module
 INIT {
 
-    # init stdout file handle to bypass Mnet::Tee for debug output
-    our $stdout = undef;
-    if ($INC{"Mnet/Tee.pm"}) {
-        $stdout = $Mnet::Tee::stdout;
-    } else {
-        open($stdout, ">&STDOUT");
-    }
-
     # init --debug option
     Mnet::Opts::Cli::define({
         getopt      => 'debug!',
@@ -307,7 +303,7 @@ sub error {
     $error = Mnet::Log::error();
 
 This function returns the first line of error text from the perl warn or die
-commands or Mnet::Log warn or fatal outputs.
+commands or Mnet::Log warn or fatal outputs, prefixed by the calling module.
 
 A value of undefined is returned if there have not yet been any errors.
 
@@ -362,7 +358,7 @@ sub output {
        and not defined $Mnet::Log::debug_error;
 
     # update global error flag with first line of first error entry
-    $Mnet::Log::error = "$caller ".(split(/\n/, $text))[0]
+    $Mnet::Log::error = "$caller, ".(split(/\n/, $text))[0]
         if $severity < 5 and not defined $Mnet::Log::error;
 
     # set hh:mm:ss timestamp for entries as long as --test is not set
@@ -420,8 +416,10 @@ sub output {
 
         # stderr sev 4 warn, sev 3 error, and sev 2 fatal
         #   included in Mnet::Tee::test_outputs
+        #   if --quiet and perl die/warn error then output original error only
         #   if --silent set then output to --tee file only
         } elsif ($severity < 5) {
+            $line = $2 if $self->{quiet} and $text =~ /^perl (die|warn),\s(.*)/;
             if ($self->{silent} and not $self->{quiet}) {
                 Mnet::Tee::tee_no_term("$line\n") if $INC{"Mnet/Tee.pm"};
             } else {
@@ -625,7 +623,7 @@ END {
     my $debug_error_file = Mnet::Opts::Cli::Cache::debug_error();
     if (defined $debug_error_file) {
         my ($sec, $min, $hr, $mday, $mon, $yr) = localtime();
-        $yr += 1900; $mday += 1;
+        $yr += 1900; $mon += 1;
         my $date_stamp = sprintf("%02s-%02s-%02s", $yr, $mon, $mday);
         my $time_stamp = sprintf("%02s:%02s:%02s", $hr, $min, $sec);
         $debug_error_file =~ s/\*/${date_stamp}_${time_stamp}_pid-$$/;
@@ -644,7 +642,7 @@ END {
     #   only if first line was output, meaning logging was enabled/used
     #   only if Mnet::Log::Test was not used to filter varying log outputs
     #   Mnet::Opts::Cli->new loads Mnet::Log::Test if --test/record/replay set
-    NOTICE("detected at least one error, $Mnet::Log::error")
+    NOTICE("detected at least one error, in $Mnet::Log::error")
         if defined $Mnet::Log::error
         and $Mnet::Log::first
         and not $INC{"Mnet/Log/Test.pm"};
