@@ -12,11 +12,16 @@ Mnet::Opts::Set::Quiet - Use this module to enable --quiet option
 
 This module can be used as a pragma to enable the L<Mnet::Log> --quiet option.
 
+Note that the --quiet and --silent options override this pragma.
+
 =cut
 
 # required modules
 use warnings;
 use strict;
+use Mnet;
+
+
 
 =head1 SEE ALSO
 
