@@ -6,6 +6,8 @@ package Mnet::T;
 use warnings;
 use strict;
 use Carp;
+use Config;
+use Mnet;
 use Test::More;
 
 
@@ -56,6 +58,14 @@ sub test_perl {
 #
 # troubleshoot a single test with: INIT { our $mnet_test_perl = $name_re }
 
+#? problem on cpantesters with grep on one sparc64-openbsd system
+#   test filters with grep get error 'grep: -: No such file or directory'
+#   no sed errors, no defined aliases, both commands in /usr/bin, in $PATH
+#   grep gives this error if run with no stdin, example: `grep test -`
+#   dosn't matter if it's one grep command, or multiple, complex or simple
+#   debuged with new if-block for not $result, syswrite stderr with extra info
+#   $Config::Config{archname} code can skip, better to simple/accurate/fail
+
     # read input specs
     my $specs = shift;
 
@@ -66,7 +76,7 @@ sub test_perl {
     # skip if global mnet_test_perl var is set and test doesn't match
     #   makes it easy to troubleshoot one test in a .t script full of tests
     if ($main::mnet_test_perl and $name !~ /\Q$main::mnet_test_perl\E/) {
-        SKIP: { skip("$name (main::mnet_test_perl dosn't match)", 1); };
+        SKIP: { skip("$name (main::mnet_test_perl)", 1); };
         return 1;
     }
 
@@ -81,7 +91,7 @@ sub test_perl {
     # append filter to test command, if one was specified
     #   remove leading and trailing blank lines before shell piping
     if ($specs->{filter}) {
-        $specs->{filter} =~ s/(^\n+|\n+$)//g;
+        $specs->{filter} =~ s/(^\s+|\s+$)//mg;
         $command .= "| $specs->{filter}";
     }
 
@@ -92,25 +102,29 @@ sub test_perl {
     $specs->{expect} =~ s/(^\n+|\n+$)//g;
 
     # get output from command, remove leading/trailing blank lines
-    ( my $output = `$command` ) =~ s/(^\n+|\n+$)//g;
+    ( my $output = `( $command ) 2>&1` ) =~ s/(^\n+|\n+$)//g;
 
     # compare command output to expected output
     #   added leading cr makes for cleaner Test::More::is output
     my $result = Test::More::is( "\n$output", "\n$specs->{expect}", $name);
 
     # re-run test with debug args if test failed and debug key was set
-    if (not $result and defined $specs->{debug}) {
-        my $output = "\npre/perl/post $specs->{debug} for failed '$name'\n";
-        $output .= "   called from $caller[1] line $caller[2]\n\n";
-        my $command = _test_perl_command($specs, "debug");
-        $output .= "COMMAND STARTING\n$command\nCOMMAND FINISHED\n";
-        $output .= "UNFILTERED OUTPUT STARTING";
-        $output .= `( export MNET_TEST_PERL_DEBUG=1; $command ) 2>&1`;
-        $output .= "UNFILTERED OUTPUT FINISHED\n";
-        $output .= "FILTER STARTING\n$specs->{filter}\nFILTER FINISHED\n"
-            if $specs->{filter};
-        syswrite STDERR, "## $_\n" foreach split(/\n/, $output);
-        syswrite STDERR, "##\n";
+    if (not $result) {
+        if ($specs->{debug} or $specs->{filter}) {
+            my $output = "\npre/perl/post debug for failed '$name'\n";
+            $output .= "   called from $caller[1] line $caller[2]\n\n";
+            my $command = _test_perl_command($specs, "debug");
+            $output .= "COMMAND STARTING\n$command\nCOMMAND FINISHED\n";
+            $output .= "UNFILTERED OUTPUT STARTING";
+            $output .= `( export MNET_TEST_PERL_DEBUG=1; $command ) 2>&1`;
+            $output .= "UNFILTERED OUTPUT FINISHED\n";
+            $output .= "FILTER STARTING\n$specs->{filter}\nFILTER FINISHED\n"
+                if $specs->{filter};
+            syswrite STDERR, "## $_\n" foreach split(/\n/, $output);
+            syswrite STDERR, "##\n";
+        } else {
+            syswrite STDERR, "##    called from $caller[1] line $caller[2]\n\n";
+        }
     }
 
     # finished test_perl function, return result
@@ -135,7 +149,7 @@ sub _test_perl_command {
 
     # append pre shell code, if specified
     if ($specs->{pre}) {
-        $specs->{pre} =~ s/\n+$//;
+        $specs->{pre} =~ s/(^\s+|\s+$)//g;
         $command .= "echo 'PRE STARTING';" if $debug;
         $command .= "$specs->{pre};";
         $command .= "echo 'PRE FINISHED'; echo;" if $debug;
@@ -146,12 +160,12 @@ sub _test_perl_command {
     ( my $perl = $specs->{perl} ) =~ s/'/'"'"'/g;
     $command .= "echo '$perl' | $^X - ";
     $command .= $specs->{args} if defined $specs->{args};
-    $command .= " " . $specs->{debug} if defined $debug;
+    $command .= " " . $specs->{debug} if $debug and defined $specs->{debug};
     $command .= ";";
 
     # append post shell code, if specified
     if ($specs->{post}) {
-        $specs->{post} =~ s/\n+$//;
+        $specs->{post} =~ s/(^\s+|\s+$)//g;
         $command .= "echo; echo 'POST STARTING';" if $debug;
         $command .= "$specs->{post};";
         $command .= "echo 'POST FINISHED';" if $debug;
